@@ -55,7 +55,11 @@ void ffPrintColors(FFColorsOptions* options)
         #ifdef __linux__
         // Required by Linux Console for light background to work
         if (options->symbol == FF_COLORS_SYMBOL_BACKGROUND)
-            ffStrbufAppendS(&result, "\e[5m");
+        {
+            const char* term = getenv("TERM");
+            if (term && ffStrEquals(term, "linux"))
+                ffStrbufAppendS(&result, "\e[5m");
+        }
         #endif
 
         // 9%d: Set the foreground to the bright color
